# Phinka tools for data processing

Launch by `python -m phinka` with `python-is-python3` installed. Help is available with the `--help` option. Check out the package source of `phinka.__main__.py` for more details.

## `blwz`

A data compression tool.